aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/notifications.h
diff options
context:
space:
mode:
authorn-peugnet <n.peugnet@free.fr>2022-10-06 19:27:24 +0200
committern-peugnet <n.peugnet@free.fr>2022-10-06 19:27:24 +0200
commitd911b207f49e936b3e992200796110f0749ed150 (patch)
tree96d20ebb4d074a4c1755e21cb316a52d584daee3 /lib/csapi/notifications.h
parent8ad8a74152c5701b6ca1f9a00487ba9257a439b4 (diff)
parent56c2f2e2b809b9077393eb617828f33d144f5634 (diff)
downloadlibquotient-d911b207f49e936b3e992200796110f0749ed150.tar.gz
libquotient-d911b207f49e936b3e992200796110f0749ed150.zip
New upstream version 0.7.0
Diffstat (limited to 'lib/csapi/notifications.h')
-rw-r--r--lib/csapi/notifications.h147
1 files changed, 78 insertions, 69 deletions
diff --git a/lib/csapi/notifications.h b/lib/csapi/notifications.h
index 898b5154..ff8aa47f 100644
--- a/lib/csapi/notifications.h
+++ b/lib/csapi/notifications.h
@@ -4,86 +4,95 @@
#pragma once
+#include "events/event.h"
#include "jobs/basejob.h"
-#include "events/eventloader.h"
-#include "converters.h"
-#include <QtCore/QVector>
-#include <QtCore/QVariant>
-#include <QtCore/QJsonObject>
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Gets a list of events that the user has been notified about
+ *
+ * This API is used to paginate through the list of events that the
+ * user has been, or would have been notified about.
+ */
+class QUOTIENT_API GetNotificationsJob : public BaseJob {
+public:
+ // Inner data structures
- /// Gets a list of events that the user has been notified about
- ///
/// This API is used to paginate through the list of events that the
/// user has been, or would have been notified about.
- class GetNotificationsJob : public BaseJob
- {
- public:
- // Inner data structures
-
- /// This API is used to paginate through the list of events that the
- /// user has been, or would have been notified about.
- struct Notification
- {
- /// The action(s) to perform when the conditions for this rule are met.
- /// See `Push Rules: API`_.
- QVector<QVariant> actions;
- /// The Event object for the event that triggered the notification.
- EventPtr event;
- /// The profile tag of the rule that matched this event.
- QString profileTag;
- /// Indicates whether the user has sent a read receipt indicating
- /// that they have read this message.
- bool read;
- /// The ID of the room in which the event was posted.
- QString roomId;
- /// The unix timestamp at which the event notification was sent,
- /// in milliseconds.
- int ts;
- };
+ struct Notification {
+ /// The action(s) to perform when the conditions for this rule are met.
+ /// See [Push Rules: API](/client-server-api/#push-rules-api).
+ QVector<QVariant> actions;
+ /// The Event object for the event that triggered the notification.
+ EventPtr event;
+ /// The profile tag of the rule that matched this event.
+ QString profileTag;
+ /// Indicates whether the user has sent a read receipt indicating
+ /// that they have read this message.
+ bool read;
+ /// The ID of the room in which the event was posted.
+ QString roomId;
+ /// The unix timestamp at which the event notification was sent,
+ /// in milliseconds.
+ qint64 ts;
+ };
- // Construction/destruction
+ // Construction/destruction
- /*! Gets a list of events that the user has been notified about
- * \param from
- * Pagination token given to retrieve the next set of events.
- * \param limit
- * Limit on the number of events to return in this request.
- * \param only
- * Allows basic filtering of events returned. Supply ``highlight``
- * to return only events where the notification had the highlight
- * tweak set.
- */
- explicit GetNotificationsJob(const QString& from = {}, Omittable<int> limit = none, const QString& only = {});
+ /*! \brief Gets a list of events that the user has been notified about
+ *
+ * \param from
+ * Pagination token to continue from. This should be the `next_token`
+ * returned from an earlier call to this endpoint.
+ *
+ * \param limit
+ * Limit on the number of events to return in this request.
+ *
+ * \param only
+ * Allows basic filtering of events returned. Supply `highlight`
+ * to return only events where the notification had the highlight
+ * tweak set.
+ */
+ explicit GetNotificationsJob(const QString& from = {},
+ Omittable<int> limit = none,
+ const QString& only = {});
- /*! Construct a URL without creating a full-fledged job object
- *
- * This function can be used when a URL for
- * GetNotificationsJob is necessary but the job
- * itself isn't.
- */
- static QUrl makeRequestUrl(QUrl baseUrl, const QString& from = {}, Omittable<int> limit = none, const QString& only = {});
+ /*! \brief Construct a URL without creating a full-fledged job object
+ *
+ * This function can be used when a URL for GetNotificationsJob
+ * is necessary but the job itself isn't.
+ */
+ static QUrl makeRequestUrl(QUrl baseUrl, const QString& from = {},
+ Omittable<int> limit = none,
+ const QString& only = {});
- ~GetNotificationsJob() override;
+ // Result properties
- // Result properties
+ /// The token to supply in the `from` param of the next
+ /// `/notifications` request in order to request more
+ /// events. If this is absent, there are no more results.
+ QString nextToken() const { return loadFromJson<QString>("next_token"_ls); }
- /// The token to supply in the ``from`` param of the next
- /// ``/notifications`` request in order to request more
- /// events. If this is absent, there are no more results.
- const QString& nextToken() const;
- /// The list of events that triggered notifications.
- std::vector<Notification>&& notifications();
+ /// The list of events that triggered notifications.
+ std::vector<Notification> notifications()
+ {
+ return takeFromJson<std::vector<Notification>>("notifications"_ls);
+ }
+};
- protected:
- Status parseJson(const QJsonDocument& data) override;
+template <>
+struct JsonObjectConverter<GetNotificationsJob::Notification> {
+ static void fillFrom(const QJsonObject& jo,
+ GetNotificationsJob::Notification& result)
+ {
+ fromJson(jo.value("actions"_ls), result.actions);
+ fromJson(jo.value("event"_ls), result.event);
+ fromJson(jo.value("profile_tag"_ls), result.profileTag);
+ fromJson(jo.value("read"_ls), result.read);
+ fromJson(jo.value("room_id"_ls), result.roomId);
+ fromJson(jo.value("ts"_ls), result.ts);
+ }
+};
- private:
- class Private;
- QScopedPointer<Private> d;
- };
-} // namespace QMatrixClient
+} // namespace Quotient